# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: yandex/cloud/apploadbalancer/v1/load_balancer_service.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.api import annotations_pb2 as google_dot_api_dot_annotations__pb2
from google.protobuf import field_mask_pb2 as google_dot_protobuf_dot_field__mask__pb2
from yandex.cloud.api import operation_pb2 as yandex_dot_cloud_dot_api_dot_operation__pb2
from yandex.cloud.operation import operation_pb2 as yandex_dot_cloud_dot_operation_dot_operation__pb2
from yandex.cloud.apploadbalancer.v1 import load_balancer_pb2 as yandex_dot_cloud_dot_apploadbalancer_dot_v1_dot_load__balancer__pb2
from yandex.cloud.apploadbalancer.v1 import logging_pb2 as yandex_dot_cloud_dot_apploadbalancer_dot_v1_dot_logging__pb2
from yandex.cloud import validation_pb2 as yandex_dot_cloud_dot_validation__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='yandex/cloud/apploadbalancer/v1/load_balancer_service.proto',
  package='yandex.cloud.apploadbalancer.v1',
  syntax='proto3',
  serialized_options=b'\n#yandex.cloud.api.apploadbalancer.v1ZSgithub.com/yandex-cloud/go-genproto/yandex/cloud/apploadbalancer/v1;apploadbalancer',
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\n;yandex/cloud/apploadbalancer/v1/load_balancer_service.proto\x12\x1fyandex.cloud.apploadbalancer.v1\x1a\x1cgoogle/api/annotations.proto\x1a google/protobuf/field_mask.proto\x1a yandex/cloud/api/operation.proto\x1a&yandex/cloud/operation/operation.proto\x1a\x33yandex/cloud/apploadbalancer/v1/load_balancer.proto\x1a-yandex/cloud/apploadbalancer/v1/logging.proto\x1a\x1dyandex/cloud/validation.proto\"8\n\x16GetLoadBalancerRequest\x12\x1e\n\x10load_balancer_id\x18\x01 \x01(\tB\x04\xe8\xc7\x31\x01\"\x8d\x01\n\x18ListLoadBalancersRequest\x12\x17\n\tfolder_id\x18\x01 \x01(\tB\x04\xe8\xc7\x31\x01\x12\x1d\n\tpage_size\x18\x02 \x01(\x03\x42\n\xfa\xc7\x31\x06\x30-1000\x12\x1d\n\npage_token\x18\x03 \x01(\tB\t\x8a\xc8\x31\x05<=100\x12\x1a\n\x06\x66ilter\x18\x04 \x01(\tB\n\x8a\xc8\x31\x06<=1000\"{\n\x19ListLoadBalancersResponse\x12\x45\n\x0eload_balancers\x18\x01 \x03(\x0b\x32-.yandex.cloud.apploadbalancer.v1.LoadBalancer\x12\x17\n\x0fnext_page_token\x18\x02 \x01(\t\";\n\x19\x44\x65leteLoadBalancerRequest\x12\x1e\n\x10load_balancer_id\x18\x01 \x01(\tB\x04\xe8\xc7\x31\x01\"6\n\x1a\x44\x65leteLoadBalancerMetadata\x12\x18\n\x10load_balancer_id\x18\x01 \x01(\t\"\xd3\x05\n\x19UpdateLoadBalancerRequest\x12\x1e\n\x10load_balancer_id\x18\x01 \x01(\tB\x04\xe8\xc7\x31\x01\x12/\n\x0bupdate_mask\x18\x02 \x01(\x0b\x32\x1a.google.protobuf.FieldMask\x12\x34\n\x04name\x18\x03 \x01(\tB&\xf2\xc7\x31\"([a-z]([-a-z0-9]{0,61}[a-z0-9])?)?\x12\x1e\n\x0b\x64\x65scription\x18\x04 \x01(\tB\t\x8a\xc8\x31\x05<=256\x12\x9f\x01\n\x06labels\x18\x05 \x03(\x0b\x32\x46.yandex.cloud.apploadbalancer.v1.UpdateLoadBalancerRequest.LabelsEntryBG\x82\xc8\x31\x04<=64\x8a\xc8\x31\x04<=63\xf2\xc7\x31\x0f[-_./\\@0-9a-z]*\xb2\xc8\x31\x06\x1a\x04\x31-63\xb2\xc8\x31\x16\x12\x14[a-z][-_./\\@0-9a-z]*\x12\x45\n\x0elistener_specs\x18\x06 \x03(\x0b\x32-.yandex.cloud.apploadbalancer.v1.ListenerSpec\x12L\n\x11\x61llocation_policy\x18\x07 \x01(\x0b\x32\x31.yandex.cloud.apploadbalancer.v1.AllocationPolicy\x12\x1a\n\x12security_group_ids\x18\x08 \x03(\t\x12K\n\x11\x61uto_scale_policy\x18\t \x01(\x0b\x32\x30.yandex.cloud.apploadbalancer.v1.AutoScalePolicy\x12@\n\x0blog_options\x18\n \x01(\x0b\x32+.yandex.cloud.apploadbalancer.v1.LogOptions\x1a-\n\x0bLabelsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"6\n\x1aUpdateLoadBalancerMetadata\x12\x18\n\x10load_balancer_id\x18\x01 \x01(\t\"\xce\x05\n\x19\x43reateLoadBalancerRequest\x12\x17\n\tfolder_id\x18\x01 \x01(\tB\x04\xe8\xc7\x31\x01\x12\x34\n\x04name\x18\x02 \x01(\tB&\xf2\xc7\x31\"([a-z]([-a-z0-9]{0,61}[a-z0-9])?)?\x12\x1e\n\x0b\x64\x65scription\x18\x03 \x01(\tB\t\x8a\xc8\x31\x05<=256\x12\x9f\x01\n\x06labels\x18\x04 \x03(\x0b\x32\x46.yandex.cloud.apploadbalancer.v1.CreateLoadBalancerRequest.LabelsEntryBG\x82\xc8\x31\x04<=64\x8a\xc8\x31\x04<=63\xf2\xc7\x31\x0f[-_./\\@0-9a-z]*\xb2\xc8\x31\x06\x1a\x04\x31-63\xb2\xc8\x31\x16\x12\x14[a-z][-_./\\@0-9a-z]*\x12\x17\n\tregion_id\x18\x05 \x01(\tB\x04\xe8\xc7\x31\x01\x12\x18\n\nnetwork_id\x18\x06 \x01(\tB\x04\xe8\xc7\x31\x01\x12\x45\n\x0elistener_specs\x18\x07 \x03(\x0b\x32-.yandex.cloud.apploadbalancer.v1.ListenerSpec\x12L\n\x11\x61llocation_policy\x18\x08 \x01(\x0b\x32\x31.yandex.cloud.apploadbalancer.v1.AllocationPolicy\x12\x1a\n\x12security_group_ids\x18\t \x03(\t\x12K\n\x11\x61uto_scale_policy\x18\n \x01(\x0b\x32\x30.yandex.cloud.apploadbalancer.v1.AutoScalePolicy\x12@\n\x0blog_options\x18\x0b \x01(\x0b\x32+.yandex.cloud.apploadbalancer.v1.LogOptions\x1a-\n\x0bLabelsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"6\n\x1a\x43reateLoadBalancerMetadata\x12\x18\n\x10load_balancer_id\x18\x01 \x01(\t\":\n\x18StartLoadBalancerRequest\x12\x1e\n\x10load_balancer_id\x18\x01 \x01(\tB\x04\xe8\xc7\x31\x01\"5\n\x19StartLoadBalancerMetadata\x12\x18\n\x10load_balancer_id\x18\x01 \x01(\t\"9\n\x17StopLoadBalancerRequest\x12\x1e\n\x10load_balancer_id\x18\x01 \x01(\tB\x04\xe8\xc7\x31\x01\"4\n\x18StopLoadBalancerMetadata\x12\x18\n\x10load_balancer_id\x18\x01 \x01(\t\"\x80\x01\n\x12\x41\x64\x64ListenerRequest\x12\x1e\n\x10load_balancer_id\x18\x01 \x01(\tB\x04\xe8\xc7\x31\x01\x12J\n\rlistener_spec\x18\x02 \x01(\x0b\x32-.yandex.cloud.apploadbalancer.v1.ListenerSpecB\x04\xe8\xc7\x31\x01\"F\n\x13\x41\x64\x64ListenerMetadata\x12\x18\n\x10load_balancer_id\x18\x01 \x01(\t\x12\x15\n\rlistener_name\x18\x02 \x01(\t\"K\n\x15RemoveListenerRequest\x12\x1e\n\x10load_balancer_id\x18\x01 \x01(\tB\x04\xe8\xc7\x31\x01\x12\x12\n\x04name\x18\x02 \x01(\tB\x04\xe8\xc7\x31\x01\"I\n\x16RemoveListenerMetadata\x12\x18\n\x10load_balancer_id\x18\x01 \x01(\t\x12\x15\n\rlistener_name\x18\x02 \x01(\t\"\xb4\x01\n\x15UpdateListenerRequest\x12\x1e\n\x10load_balancer_id\x18\x01 \x01(\tB\x04\xe8\xc7\x31\x01\x12/\n\x0bupdate_mask\x18\x02 \x01(\x0b\x32\x1a.google.protobuf.FieldMask\x12J\n\rlistener_spec\x18\x03 \x01(\x0b\x32-.yandex.cloud.apploadbalancer.v1.ListenerSpecB\x04\xe8\xc7\x31\x01\"I\n\x16UpdateListenerMetadata\x12\x18\n\x10load_balancer_id\x18\x01 \x01(\t\x12\x15\n\rlistener_name\x18\x02 \x01(\t\"\xc3\x02\n\x0b\x41\x64\x64ressSpec\x12^\n\x1a\x65xternal_ipv4_address_spec\x18\x01 \x01(\x0b\x32\x38.yandex.cloud.apploadbalancer.v1.ExternalIpv4AddressSpecH\x00\x12^\n\x1ainternal_ipv4_address_spec\x18\x02 \x01(\x0b\x32\x38.yandex.cloud.apploadbalancer.v1.InternalIpv4AddressSpecH\x00\x12^\n\x1a\x65xternal_ipv6_address_spec\x18\x03 \x01(\x0b\x32\x38.yandex.cloud.apploadbalancer.v1.ExternalIpv6AddressSpecH\x00\x42\x14\n\x0c\x61\x64\x64ress_spec\x12\x04\xc0\xc1\x31\x01\"*\n\x17\x45xternalIpv4AddressSpec\x12\x0f\n\x07\x61\x64\x64ress\x18\x01 \x01(\t\"=\n\x17InternalIpv4AddressSpec\x12\x0f\n\x07\x61\x64\x64ress\x18\x01 \x01(\t\x12\x11\n\tsubnet_id\x18\x02 \x01(\t\"*\n\x17\x45xternalIpv6AddressSpec\x12\x0f\n\x07\x61\x64\x64ress\x18\x01 \x01(\t\"}\n\x0c\x45ndpointSpec\x12K\n\raddress_specs\x18\x01 \x03(\x0b\x32,.yandex.cloud.apploadbalancer.v1.AddressSpecB\x06\x82\xc8\x31\x02>0\x12 \n\x05ports\x18\x02 \x03(\x03\x42\x11\x82\xc8\x31\x02>0\xfa\xc7\x31\x07\x31-65535\"\xe5\x02\n\x0cListenerSpec\x12\x35\n\x04name\x18\x01 \x01(\tB\'\xe8\xc7\x31\x01\xf2\xc7\x31\x1f[a-z]([-a-z0-9]{0,61}[a-z0-9])?\x12M\n\x0e\x65ndpoint_specs\x18\x02 \x03(\x0b\x32-.yandex.cloud.apploadbalancer.v1.EndpointSpecB\x06\x82\xc8\x31\x02>0\x12=\n\x04http\x18\x03 \x01(\x0b\x32-.yandex.cloud.apploadbalancer.v1.HttpListenerH\x00\x12;\n\x03tls\x18\x04 \x01(\x0b\x32,.yandex.cloud.apploadbalancer.v1.TlsListenerH\x00\x12\x41\n\x06stream\x18\x05 \x01(\x0b\x32/.yandex.cloud.apploadbalancer.v1.StreamListenerH\x00\x42\x10\n\x08listener\x12\x04\xc0\xc1\x31\x01\"w\n\x16GetTargetStatesRequest\x12\x1e\n\x10load_balancer_id\x18\x01 \x01(\tB\x04\xe8\xc7\x31\x01\x12\x1e\n\x10\x62\x61\x63kend_group_id\x18\x02 \x01(\tB\x04\xe8\xc7\x31\x01\x12\x1d\n\x0ftarget_group_id\x18\x03 \x01(\tB\x04\xe8\xc7\x31\x01\"^\n\x17GetTargetStatesResponse\x12\x43\n\rtarget_states\x18\x01 \x03(\x0b\x32,.yandex.cloud.apploadbalancer.v1.TargetState\"\xc7\x01\n\x12\x41\x64\x64SniMatchRequest\x12\x1e\n\x10load_balancer_id\x18\x01 \x01(\tB\x04\xe8\xc7\x31\x01\x12\x1b\n\rlistener_name\x18\x02 \x01(\tB\x04\xe8\xc7\x31\x01\x12\x12\n\x04name\x18\x03 \x01(\tB\x04\xe8\xc7\x31\x01\x12\x1c\n\x0cserver_names\x18\x04 \x03(\tB\x06\x82\xc8\x31\x02>0\x12\x42\n\x07handler\x18\x05 \x01(\x0b\x32+.yandex.cloud.apploadbalancer.v1.TlsHandlerB\x04\xe8\xc7\x31\x01\"^\n\x13\x41\x64\x64SniMatchMetadata\x12\x18\n\x10load_balancer_id\x18\x01 \x01(\t\x12\x15\n\rlistener_name\x18\x02 \x01(\t\x12\x16\n\x0esni_match_name\x18\x03 \x01(\t\"r\n\x15RemoveSniMatchRequest\x12\x1e\n\x10load_balancer_id\x18\x01 \x01(\tB\x04\xe8\xc7\x31\x01\x12\x1b\n\rlistener_name\x18\x02 \x01(\tB\x04\xe8\xc7\x31\x01\x12\x1c\n\x0esni_match_name\x18\x03 \x01(\tB\x04\xe8\xc7\x31\x01\"a\n\x16RemoveSniMatchMetadata\x12\x18\n\x10load_balancer_id\x18\x01 \x01(\t\x12\x15\n\rlistener_name\x18\x02 \x01(\t\x12\x16\n\x0esni_match_name\x18\x03 \x01(\t\"\xfb\x01\n\x15UpdateSniMatchRequest\x12\x1e\n\x10load_balancer_id\x18\x01 \x01(\tB\x04\xe8\xc7\x31\x01\x12\x1b\n\rlistener_name\x18\x02 \x01(\tB\x04\xe8\xc7\x31\x01\x12\x12\n\x04name\x18\x03 \x01(\tB\x04\xe8\xc7\x31\x01\x12/\n\x0bupdate_mask\x18\x04 \x01(\x0b\x32\x1a.google.protobuf.FieldMask\x12\x1c\n\x0cserver_names\x18\x05 \x03(\tB\x06\x82\xc8\x31\x02>0\x12\x42\n\x07handler\x18\x06 \x01(\x0b\x32+.yandex.cloud.apploadbalancer.v1.TlsHandlerB\x04\xe8\xc7\x31\x01\"a\n\x16UpdateSniMatchMetadata\x12\x18\n\x10load_balancer_id\x18\x01 \x01(\t\x12\x15\n\rlistener_name\x18\x02 \x01(\t\x12\x16\n\x0esni_match_name\x18\x03 \x01(\t\"\x89\x01\n!ListLoadBalancerOperationsRequest\x12&\n\x10load_balancer_id\x18\x01 \x01(\tB\x0c\xe8\xc7\x31\x01\x8a\xc8\x31\x04<=50\x12\x1d\n\tpage_size\x18\x02 \x01(\x03\x42\n\xfa\xc7\x31\x06<=1000\x12\x1d\n\npage_token\x18\x03 \x01(\tB\t\x8a\xc8\x31\x05<=100\"t\n\"ListLoadBalancerOperationsResponse\x12\x35\n\noperations\x18\x01 \x03(\x0b\x32!.yandex.cloud.operation.Operation\x12\x17\n\x0fnext_page_token\x18\x02 \x01(\t2\xeb\x19\n\x13LoadBalancerService\x12\xab\x01\n\x03Get\x12\x37.yandex.cloud.apploadbalancer.v1.GetLoadBalancerRequest\x1a-.yandex.cloud.apploadbalancer.v1.LoadBalancer\"<\x82\xd3\xe4\x93\x02\x36\x12\x34/apploadbalancer/v1/loadBalancers/{load_balancer_id}\x12\xa8\x01\n\x04List\x12\x39.yandex.cloud.apploadbalancer.v1.ListLoadBalancersRequest\x1a:.yandex.cloud.apploadbalancer.v1.ListLoadBalancersResponse\")\x82\xd3\xe4\x93\x02#\x12!/apploadbalancer/v1/loadBalancers\x12\xc3\x01\n\x06\x43reate\x12:.yandex.cloud.apploadbalancer.v1.CreateLoadBalancerRequest\x1a!.yandex.cloud.operation.Operation\"Z\x82\xd3\xe4\x93\x02&\"!/apploadbalancer/v1/loadBalancers:\x01*\xb2\xd2**\n\x1a\x43reateLoadBalancerMetadata\x12\x0cLoadBalancer\x12\xd6\x01\n\x06Update\x12:.yandex.cloud.apploadbalancer.v1.UpdateLoadBalancerRequest\x1a!.yandex.cloud.operation.Operation\"m\x82\xd3\xe4\x93\x02\x39\x32\x34/apploadbalancer/v1/loadBalancers/{load_balancer_id}:\x01*\xb2\xd2**\n\x1aUpdateLoadBalancerMetadata\x12\x0cLoadBalancer\x12\xdc\x01\n\x06\x44\x65lete\x12:.yandex.cloud.apploadbalancer.v1.DeleteLoadBalancerRequest\x1a!.yandex.cloud.operation.Operation\"s\x82\xd3\xe4\x93\x02\x36*4/apploadbalancer/v1/loadBalancers/{load_balancer_id}\xb2\xd2*3\n\x1a\x44\x65leteLoadBalancerMetadata\x12\x15google.protobuf.Empty\x12\xd6\x01\n\x05Start\x12\x39.yandex.cloud.apploadbalancer.v1.StartLoadBalancerRequest\x1a!.yandex.cloud.operation.Operation\"o\x82\xd3\xe4\x93\x02<\":/apploadbalancer/v1/loadBalancers/{load_balancer_id}:start\xb2\xd2*)\n\x19StartLoadBalancerMetadata\x12\x0cLoadBalancer\x12\xd2\x01\n\x04Stop\x12\x38.yandex.cloud.apploadbalancer.v1.StopLoadBalancerRequest\x1a!.yandex.cloud.operation.Operation\"m\x82\xd3\xe4\x93\x02;\"9/apploadbalancer/v1/loadBalancers/{load_balancer_id}:stop\xb2\xd2*(\n\x18StopLoadBalancerMetadata\x12\x0cLoadBalancer\x12\xd9\x01\n\x0b\x41\x64\x64Listener\x12\x33.yandex.cloud.apploadbalancer.v1.AddListenerRequest\x1a!.yandex.cloud.operation.Operation\"r\x82\xd3\xe4\x93\x02\x45\"@/apploadbalancer/v1/loadBalancers/{load_balancer_id}:addListener:\x01*\xb2\xd2*#\n\x13\x41\x64\x64ListenerMetadata\x12\x0cLoadBalancer\x12\xe5\x01\n\x0eRemoveListener\x12\x36.yandex.cloud.apploadbalancer.v1.RemoveListenerRequest\x1a!.yandex.cloud.operation.Operation\"x\x82\xd3\xe4\x93\x02H\"C/apploadbalancer/v1/loadBalancers/{load_balancer_id}:removeListener:\x01*\xb2\xd2*&\n\x16RemoveListenerMetadata\x12\x0cLoadBalancer\x12\xe5\x01\n\x0eUpdateListener\x12\x36.yandex.cloud.apploadbalancer.v1.UpdateListenerRequest\x1a!.yandex.cloud.operation.Operation\"x\x82\xd3\xe4\x93\x02H\"C/apploadbalancer/v1/loadBalancers/{load_balancer_id}:updateListener:\x01*\xb2\xd2*&\n\x16UpdateListenerMetadata\x12\x0cLoadBalancer\x12\xe2\x01\n\x0b\x41\x64\x64SniMatch\x12\x33.yandex.cloud.apploadbalancer.v1.AddSniMatchRequest\x1a!.yandex.cloud.operation.Operation\"{\x82\xd3\xe4\x93\x02\x45\"@/apploadbalancer/v1/loadBalancers/{load_balancer_id}:addSniMatch:\x01*\xb2\xd2*,\n\x13\x41\x64\x64SniMatchMetadata\x12\x15google.protobuf.Empty\x12\xef\x01\n\x0eUpdateSniMatch\x12\x36.yandex.cloud.apploadbalancer.v1.UpdateSniMatchRequest\x1a!.yandex.cloud.operation.Operation\"\x81\x01\x82\xd3\xe4\x93\x02H\"C/apploadbalancer/v1/loadBalancers/{load_balancer_id}:updateSniMatch:\x01*\xb2\xd2*/\n\x16UpdateSniMatchMetadata\x12\x15google.protobuf.Empty\x12\xef\x01\n\x0eRemoveSniMatch\x12\x36.yandex.cloud.apploadbalancer.v1.RemoveSniMatchRequest\x1a!.yandex.cloud.operation.Operation\"\x81\x01\x82\xd3\xe4\x93\x02H\"C/apploadbalancer/v1/loadBalancers/{load_balancer_id}:removeSniMatch:\x01*\xb2\xd2*/\n\x16RemoveSniMatchMetadata\x12\x15google.protobuf.Empty\x12\xf4\x01\n\x0fGetTargetStates\x12\x37.yandex.cloud.apploadbalancer.v1.GetTargetStatesRequest\x1a\x38.yandex.cloud.apploadbalancer.v1.GetTargetStatesResponse\"n\x82\xd3\xe4\x93\x02h\x12\x66/apploadbalancer/v1/loadBalancers/{load_balancer_id}/targetStates/{backend_group_id}/{target_group_id}\x12\xe2\x01\n\x0eListOperations\x12\x42.yandex.cloud.apploadbalancer.v1.ListLoadBalancerOperationsRequest\x1a\x43.yandex.cloud.apploadbalancer.v1.ListLoadBalancerOperationsResponse\"G\x82\xd3\xe4\x93\x02\x41\x12?/apploadbalancer/v1/loadBalancers/{load_balancer_id}/operationsBz\n#yandex.cloud.api.apploadbalancer.v1ZSgithub.com/yandex-cloud/go-genproto/yandex/cloud/apploadbalancer/v1;apploadbalancerb\x06proto3'
  ,
  dependencies=[google_dot_api_dot_annotations__pb2.DESCRIPTOR,google_dot_protobuf_dot_field__mask__pb2.DESCRIPTOR,yandex_dot_cloud_dot_api_dot_operation__pb2.DESCRIPTOR,yandex_dot_cloud_dot_operation_dot_operation__pb2.DESCRIPTOR,yandex_dot_cloud_dot_apploadbalancer_dot_v1_dot_load__balancer__pb2.DESCRIPTOR,yandex_dot_cloud_dot_apploadbalancer_dot_v1_dot_logging__pb2.DESCRIPTOR,yandex_dot_cloud_dot_validation__pb2.DESCRIPTOR,])




_GETLOADBALANCERREQUEST = _descriptor.Descriptor(
  name='GetLoadBalancerRequest',
  full_name='yandex.cloud.apploadbalancer.v1.GetLoadBalancerRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='load_balancer_id', full_name='yandex.cloud.apploadbalancer.v1.GetLoadBalancerRequest.load_balancer_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\350\3071\001', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=365,
  serialized_end=421,
)


_LISTLOADBALANCERSREQUEST = _descriptor.Descriptor(
  name='ListLoadBalancersRequest',
  full_name='yandex.cloud.apploadbalancer.v1.ListLoadBalancersRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='folder_id', full_name='yandex.cloud.apploadbalancer.v1.ListLoadBalancersRequest.folder_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\350\3071\001', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='page_size', full_name='yandex.cloud.apploadbalancer.v1.ListLoadBalancersRequest.page_size', index=1,
      number=2, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\372\3071\0060-1000', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='page_token', full_name='yandex.cloud.apploadbalancer.v1.ListLoadBalancersRequest.page_token', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\212\3101\005<=100', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='filter', full_name='yandex.cloud.apploadbalancer.v1.ListLoadBalancersRequest.filter', index=3,
      number=4, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\212\3101\006<=1000', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=424,
  serialized_end=565,
)


_LISTLOADBALANCERSRESPONSE = _descriptor.Descriptor(
  name='ListLoadBalancersResponse',
  full_name='yandex.cloud.apploadbalancer.v1.ListLoadBalancersResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='load_balancers', full_name='yandex.cloud.apploadbalancer.v1.ListLoadBalancersResponse.load_balancers', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='next_page_token', full_name='yandex.cloud.apploadbalancer.v1.ListLoadBalancersResponse.next_page_token', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=567,
  serialized_end=690,
)


_DELETELOADBALANCERREQUEST = _descriptor.Descriptor(
  name='DeleteLoadBalancerRequest',
  full_name='yandex.cloud.apploadbalancer.v1.DeleteLoadBalancerRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='load_balancer_id', full_name='yandex.cloud.apploadbalancer.v1.DeleteLoadBalancerRequest.load_balancer_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\350\3071\001', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=692,
  serialized_end=751,
)


_DELETELOADBALANCERMETADATA = _descriptor.Descriptor(
  name='DeleteLoadBalancerMetadata',
  full_name='yandex.cloud.apploadbalancer.v1.DeleteLoadBalancerMetadata',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='load_balancer_id', full_name='yandex.cloud.apploadbalancer.v1.DeleteLoadBalancerMetadata.load_balancer_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=753,
  serialized_end=807,
)


_UPDATELOADBALANCERREQUEST_LABELSENTRY = _descriptor.Descriptor(
  name='LabelsEntry',
  full_name='yandex.cloud.apploadbalancer.v1.UpdateLoadBalancerRequest.LabelsEntry',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='key', full_name='yandex.cloud.apploadbalancer.v1.UpdateLoadBalancerRequest.LabelsEntry.key', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='value', full_name='yandex.cloud.apploadbalancer.v1.UpdateLoadBalancerRequest.LabelsEntry.value', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=b'8\001',
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1488,
  serialized_end=1533,
)

_UPDATELOADBALANCERREQUEST = _descriptor.Descriptor(
  name='UpdateLoadBalancerRequest',
  full_name='yandex.cloud.apploadbalancer.v1.UpdateLoadBalancerRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='load_balancer_id', full_name='yandex.cloud.apploadbalancer.v1.UpdateLoadBalancerRequest.load_balancer_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\350\3071\001', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='update_mask', full_name='yandex.cloud.apploadbalancer.v1.UpdateLoadBalancerRequest.update_mask', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='name', full_name='yandex.cloud.apploadbalancer.v1.UpdateLoadBalancerRequest.name', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\362\3071\"([a-z]([-a-z0-9]{0,61}[a-z0-9])?)?', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='description', full_name='yandex.cloud.apploadbalancer.v1.UpdateLoadBalancerRequest.description', index=3,
      number=4, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\212\3101\005<=256', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='labels', full_name='yandex.cloud.apploadbalancer.v1.UpdateLoadBalancerRequest.labels', index=4,
      number=5, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\202\3101\004<=64\212\3101\004<=63\362\3071\017[-_./\\@0-9a-z]*\262\3101\006\032\0041-63\262\3101\026\022\024[a-z][-_./\\@0-9a-z]*', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='listener_specs', full_name='yandex.cloud.apploadbalancer.v1.UpdateLoadBalancerRequest.listener_specs', index=5,
      number=6, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='allocation_policy', full_name='yandex.cloud.apploadbalancer.v1.UpdateLoadBalancerRequest.allocation_policy', index=6,
      number=7, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='security_group_ids', full_name='yandex.cloud.apploadbalancer.v1.UpdateLoadBalancerRequest.security_group_ids', index=7,
      number=8, type=9, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='auto_scale_policy', full_name='yandex.cloud.apploadbalancer.v1.UpdateLoadBalancerRequest.auto_scale_policy', index=8,
      number=9, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='log_options', full_name='yandex.cloud.apploadbalancer.v1.UpdateLoadBalancerRequest.log_options', index=9,
      number=10, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[_UPDATELOADBALANCERREQUEST_LABELSENTRY, ],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=810,
  serialized_end=1533,
)


_UPDATELOADBALANCERMETADATA = _descriptor.Descriptor(
  name='UpdateLoadBalancerMetadata',
  full_name='yandex.cloud.apploadbalancer.v1.UpdateLoadBalancerMetadata',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='load_balancer_id', full_name='yandex.cloud.apploadbalancer.v1.UpdateLoadBalancerMetadata.load_balancer_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1535,
  serialized_end=1589,
)


_CREATELOADBALANCERREQUEST_LABELSENTRY = _descriptor.Descriptor(
  name='LabelsEntry',
  full_name='yandex.cloud.apploadbalancer.v1.CreateLoadBalancerRequest.LabelsEntry',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='key', full_name='yandex.cloud.apploadbalancer.v1.CreateLoadBalancerRequest.LabelsEntry.key', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='value', full_name='yandex.cloud.apploadbalancer.v1.CreateLoadBalancerRequest.LabelsEntry.value', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=b'8\001',
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1488,
  serialized_end=1533,
)

_CREATELOADBALANCERREQUEST = _descriptor.Descriptor(
  name='CreateLoadBalancerRequest',
  full_name='yandex.cloud.apploadbalancer.v1.CreateLoadBalancerRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='folder_id', full_name='yandex.cloud.apploadbalancer.v1.CreateLoadBalancerRequest.folder_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\350\3071\001', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='name', full_name='yandex.cloud.apploadbalancer.v1.CreateLoadBalancerRequest.name', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\362\3071\"([a-z]([-a-z0-9]{0,61}[a-z0-9])?)?', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='description', full_name='yandex.cloud.apploadbalancer.v1.CreateLoadBalancerRequest.description', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\212\3101\005<=256', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='labels', full_name='yandex.cloud.apploadbalancer.v1.CreateLoadBalancerRequest.labels', index=3,
      number=4, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\202\3101\004<=64\212\3101\004<=63\362\3071\017[-_./\\@0-9a-z]*\262\3101\006\032\0041-63\262\3101\026\022\024[a-z][-_./\\@0-9a-z]*', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='region_id', full_name='yandex.cloud.apploadbalancer.v1.CreateLoadBalancerRequest.region_id', index=4,
      number=5, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\350\3071\001', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='network_id', full_name='yandex.cloud.apploadbalancer.v1.CreateLoadBalancerRequest.network_id', index=5,
      number=6, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\350\3071\001', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='listener_specs', full_name='yandex.cloud.apploadbalancer.v1.CreateLoadBalancerRequest.listener_specs', index=6,
      number=7, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='allocation_policy', full_name='yandex.cloud.apploadbalancer.v1.CreateLoadBalancerRequest.allocation_policy', index=7,
      number=8, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='security_group_ids', full_name='yandex.cloud.apploadbalancer.v1.CreateLoadBalancerRequest.security_group_ids', index=8,
      number=9, type=9, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='auto_scale_policy', full_name='yandex.cloud.apploadbalancer.v1.CreateLoadBalancerRequest.auto_scale_policy', index=9,
      number=10, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='log_options', full_name='yandex.cloud.apploadbalancer.v1.CreateLoadBalancerRequest.log_options', index=10,
      number=11, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[_CREATELOADBALANCERREQUEST_LABELSENTRY, ],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1592,
  serialized_end=2310,
)


_CREATELOADBALANCERMETADATA = _descriptor.Descriptor(
  name='CreateLoadBalancerMetadata',
  full_name='yandex.cloud.apploadbalancer.v1.CreateLoadBalancerMetadata',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='load_balancer_id', full_name='yandex.cloud.apploadbalancer.v1.CreateLoadBalancerMetadata.load_balancer_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2312,
  serialized_end=2366,
)


_STARTLOADBALANCERREQUEST = _descriptor.Descriptor(
  name='StartLoadBalancerRequest',
  full_name='yandex.cloud.apploadbalancer.v1.StartLoadBalancerRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='load_balancer_id', full_name='yandex.cloud.apploadbalancer.v1.StartLoadBalancerRequest.load_balancer_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\350\3071\001', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2368,
  serialized_end=2426,
)


_STARTLOADBALANCERMETADATA = _descriptor.Descriptor(
  name='StartLoadBalancerMetadata',
  full_name='yandex.cloud.apploadbalancer.v1.StartLoadBalancerMetadata',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='load_balancer_id', full_name='yandex.cloud.apploadbalancer.v1.StartLoadBalancerMetadata.load_balancer_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2428,
  serialized_end=2481,
)


_STOPLOADBALANCERREQUEST = _descriptor.Descriptor(
  name='StopLoadBalancerRequest',
  full_name='yandex.cloud.apploadbalancer.v1.StopLoadBalancerRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='load_balancer_id', full_name='yandex.cloud.apploadbalancer.v1.StopLoadBalancerRequest.load_balancer_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\350\3071\001', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2483,
  serialized_end=2540,
)


_STOPLOADBALANCERMETADATA = _descriptor.Descriptor(
  name='StopLoadBalancerMetadata',
  full_name='yandex.cloud.apploadbalancer.v1.StopLoadBalancerMetadata',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='load_balancer_id', full_name='yandex.cloud.apploadbalancer.v1.StopLoadBalancerMetadata.load_balancer_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2542,
  serialized_end=2594,
)


_ADDLISTENERREQUEST = _descriptor.Descriptor(
  name='AddListenerRequest',
  full_name='yandex.cloud.apploadbalancer.v1.AddListenerRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='load_balancer_id', full_name='yandex.cloud.apploadbalancer.v1.AddListenerRequest.load_balancer_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\350\3071\001', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='listener_spec', full_name='yandex.cloud.apploadbalancer.v1.AddListenerRequest.listener_spec', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\350\3071\001', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2597,
  serialized_end=2725,
)


_ADDLISTENERMETADATA = _descriptor.Descriptor(
  name='AddListenerMetadata',
  full_name='yandex.cloud.apploadbalancer.v1.AddListenerMetadata',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='load_balancer_id', full_name='yandex.cloud.apploadbalancer.v1.AddListenerMetadata.load_balancer_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='listener_name', full_name='yandex.cloud.apploadbalancer.v1.AddListenerMetadata.listener_name', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2727,
  serialized_end=2797,
)


_REMOVELISTENERREQUEST = _descriptor.Descriptor(
  name='RemoveListenerRequest',
  full_name='yandex.cloud.apploadbalancer.v1.RemoveListenerRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='load_balancer_id', full_name='yandex.cloud.apploadbalancer.v1.RemoveListenerRequest.load_balancer_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\350\3071\001', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='name', full_name='yandex.cloud.apploadbalancer.v1.RemoveListenerRequest.name', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\350\3071\001', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2799,
  serialized_end=2874,
)


_REMOVELISTENERMETADATA = _descriptor.Descriptor(
  name='RemoveListenerMetadata',
  full_name='yandex.cloud.apploadbalancer.v1.RemoveListenerMetadata',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='load_balancer_id', full_name='yandex.cloud.apploadbalancer.v1.RemoveListenerMetadata.load_balancer_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='listener_name', full_name='yandex.cloud.apploadbalancer.v1.RemoveListenerMetadata.listener_name', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2876,
  serialized_end=2949,
)


_UPDATELISTENERREQUEST = _descriptor.Descriptor(
  name='UpdateListenerRequest',
  full_name='yandex.cloud.apploadbalancer.v1.UpdateListenerRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='load_balancer_id', full_name='yandex.cloud.apploadbalancer.v1.UpdateListenerRequest.load_balancer_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\350\3071\001', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='update_mask', full_name='yandex.cloud.apploadbalancer.v1.UpdateListenerRequest.update_mask', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='listener_spec', full_name='yandex.cloud.apploadbalancer.v1.UpdateListenerRequest.listener_spec', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\350\3071\001', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2952,
  serialized_end=3132,
)


_UPDATELISTENERMETADATA = _descriptor.Descriptor(
  name='UpdateListenerMetadata',
  full_name='yandex.cloud.apploadbalancer.v1.UpdateListenerMetadata',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='load_balancer_id', full_name='yandex.cloud.apploadbalancer.v1.UpdateListenerMetadata.load_balancer_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='listener_name', full_name='yandex.cloud.apploadbalancer.v1.UpdateListenerMetadata.listener_name', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=3134,
  serialized_end=3207,
)


_ADDRESSSPEC = _descriptor.Descriptor(
  name='AddressSpec',
  full_name='yandex.cloud.apploadbalancer.v1.AddressSpec',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='external_ipv4_address_spec', full_name='yandex.cloud.apploadbalancer.v1.AddressSpec.external_ipv4_address_spec', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='internal_ipv4_address_spec', full_name='yandex.cloud.apploadbalancer.v1.AddressSpec.internal_ipv4_address_spec', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='external_ipv6_address_spec', full_name='yandex.cloud.apploadbalancer.v1.AddressSpec.external_ipv6_address_spec', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
    _descriptor.OneofDescriptor(
      name='address_spec', full_name='yandex.cloud.apploadbalancer.v1.AddressSpec.address_spec',
      index=0, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[], serialized_options=b'\300\3011\001'),
  ],
  serialized_start=3210,
  serialized_end=3533,
)


_EXTERNALIPV4ADDRESSSPEC = _descriptor.Descriptor(
  name='ExternalIpv4AddressSpec',
  full_name='yandex.cloud.apploadbalancer.v1.ExternalIpv4AddressSpec',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='address', full_name='yandex.cloud.apploadbalancer.v1.ExternalIpv4AddressSpec.address', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=3535,
  serialized_end=3577,
)


_INTERNALIPV4ADDRESSSPEC = _descriptor.Descriptor(
  name='InternalIpv4AddressSpec',
  full_name='yandex.cloud.apploadbalancer.v1.InternalIpv4AddressSpec',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='address', full_name='yandex.cloud.apploadbalancer.v1.InternalIpv4AddressSpec.address', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='subnet_id', full_name='yandex.cloud.apploadbalancer.v1.InternalIpv4AddressSpec.subnet_id', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=3579,
  serialized_end=3640,
)


_EXTERNALIPV6ADDRESSSPEC = _descriptor.Descriptor(
  name='ExternalIpv6AddressSpec',
  full_name='yandex.cloud.apploadbalancer.v1.ExternalIpv6AddressSpec',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='address', full_name='yandex.cloud.apploadbalancer.v1.ExternalIpv6AddressSpec.address', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=3642,
  serialized_end=3684,
)


_ENDPOINTSPEC = _descriptor.Descriptor(
  name='EndpointSpec',
  full_name='yandex.cloud.apploadbalancer.v1.EndpointSpec',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='address_specs', full_name='yandex.cloud.apploadbalancer.v1.EndpointSpec.address_specs', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\202\3101\002>0', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='ports', full_name='yandex.cloud.apploadbalancer.v1.EndpointSpec.ports', index=1,
      number=2, type=3, cpp_type=2, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\202\3101\002>0\372\3071\0071-65535', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=3686,
  serialized_end=3811,
)


_LISTENERSPEC = _descriptor.Descriptor(
  name='ListenerSpec',
  full_name='yandex.cloud.apploadbalancer.v1.ListenerSpec',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='name', full_name='yandex.cloud.apploadbalancer.v1.ListenerSpec.name', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\350\3071\001\362\3071\037[a-z]([-a-z0-9]{0,61}[a-z0-9])?', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='endpoint_specs', full_name='yandex.cloud.apploadbalancer.v1.ListenerSpec.endpoint_specs', index=1,
      number=2, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\202\3101\002>0', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='http', full_name='yandex.cloud.apploadbalancer.v1.ListenerSpec.http', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='tls', full_name='yandex.cloud.apploadbalancer.v1.ListenerSpec.tls', index=3,
      number=4, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='stream', full_name='yandex.cloud.apploadbalancer.v1.ListenerSpec.stream', index=4,
      number=5, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
    _descriptor.OneofDescriptor(
      name='listener', full_name='yandex.cloud.apploadbalancer.v1.ListenerSpec.listener',
      index=0, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[], serialized_options=b'\300\3011\001'),
  ],
  serialized_start=3814,
  serialized_end=4171,
)


_GETTARGETSTATESREQUEST = _descriptor.Descriptor(
  name='GetTargetStatesRequest',
  full_name='yandex.cloud.apploadbalancer.v1.GetTargetStatesRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='load_balancer_id', full_name='yandex.cloud.apploadbalancer.v1.GetTargetStatesRequest.load_balancer_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\350\3071\001', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='backend_group_id', full_name='yandex.cloud.apploadbalancer.v1.GetTargetStatesRequest.backend_group_id', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\350\3071\001', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='target_group_id', full_name='yandex.cloud.apploadbalancer.v1.GetTargetStatesRequest.target_group_id', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\350\3071\001', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=4173,
  serialized_end=4292,
)


_GETTARGETSTATESRESPONSE = _descriptor.Descriptor(
  name='GetTargetStatesResponse',
  full_name='yandex.cloud.apploadbalancer.v1.GetTargetStatesResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='target_states', full_name='yandex.cloud.apploadbalancer.v1.GetTargetStatesResponse.target_states', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=4294,
  serialized_end=4388,
)


_ADDSNIMATCHREQUEST = _descriptor.Descriptor(
  name='AddSniMatchRequest',
  full_name='yandex.cloud.apploadbalancer.v1.AddSniMatchRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='load_balancer_id', full_name='yandex.cloud.apploadbalancer.v1.AddSniMatchRequest.load_balancer_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\350\3071\001', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='listener_name', full_name='yandex.cloud.apploadbalancer.v1.AddSniMatchRequest.listener_name', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\350\3071\001', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='name', full_name='yandex.cloud.apploadbalancer.v1.AddSniMatchRequest.name', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\350\3071\001', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='server_names', full_name='yandex.cloud.apploadbalancer.v1.AddSniMatchRequest.server_names', index=3,
      number=4, type=9, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\202\3101\002>0', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='handler', full_name='yandex.cloud.apploadbalancer.v1.AddSniMatchRequest.handler', index=4,
      number=5, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\350\3071\001', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=4391,
  serialized_end=4590,
)


_ADDSNIMATCHMETADATA = _descriptor.Descriptor(
  name='AddSniMatchMetadata',
  full_name='yandex.cloud.apploadbalancer.v1.AddSniMatchMetadata',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='load_balancer_id', full_name='yandex.cloud.apploadbalancer.v1.AddSniMatchMetadata.load_balancer_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='listener_name', full_name='yandex.cloud.apploadbalancer.v1.AddSniMatchMetadata.listener_name', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='sni_match_name', full_name='yandex.cloud.apploadbalancer.v1.AddSniMatchMetadata.sni_match_name', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=4592,
  serialized_end=4686,
)


_REMOVESNIMATCHREQUEST = _descriptor.Descriptor(
  name='RemoveSniMatchRequest',
  full_name='yandex.cloud.apploadbalancer.v1.RemoveSniMatchRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='load_balancer_id', full_name='yandex.cloud.apploadbalancer.v1.RemoveSniMatchRequest.load_balancer_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\350\3071\001', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='listener_name', full_name='yandex.cloud.apploadbalancer.v1.RemoveSniMatchRequest.listener_name', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\350\3071\001', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='sni_match_name', full_name='yandex.cloud.apploadbalancer.v1.RemoveSniMatchRequest.sni_match_name', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\350\3071\001', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=4688,
  serialized_end=4802,
)


_REMOVESNIMATCHMETADATA = _descriptor.Descriptor(
  name='RemoveSniMatchMetadata',
  full_name='yandex.cloud.apploadbalancer.v1.RemoveSniMatchMetadata',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='load_balancer_id', full_name='yandex.cloud.apploadbalancer.v1.RemoveSniMatchMetadata.load_balancer_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='listener_name', full_name='yandex.cloud.apploadbalancer.v1.RemoveSniMatchMetadata.listener_name', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='sni_match_name', full_name='yandex.cloud.apploadbalancer.v1.RemoveSniMatchMetadata.sni_match_name', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=4804,
  serialized_end=4901,
)


_UPDATESNIMATCHREQUEST = _descriptor.Descriptor(
  name='UpdateSniMatchRequest',
  full_name='yandex.cloud.apploadbalancer.v1.UpdateSniMatchRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='load_balancer_id', full_name='yandex.cloud.apploadbalancer.v1.UpdateSniMatchRequest.load_balancer_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\350\3071\001', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='listener_name', full_name='yandex.cloud.apploadbalancer.v1.UpdateSniMatchRequest.listener_name', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\350\3071\001', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='name', full_name='yandex.cloud.apploadbalancer.v1.UpdateSniMatchRequest.name', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\350\3071\001', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='update_mask', full_name='yandex.cloud.apploadbalancer.v1.UpdateSniMatchRequest.update_mask', index=3,
      number=4, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='server_names', full_name='yandex.cloud.apploadbalancer.v1.UpdateSniMatchRequest.server_names', index=4,
      number=5, type=9, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\202\3101\002>0', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='handler', full_name='yandex.cloud.apploadbalancer.v1.UpdateSniMatchRequest.handler', index=5,
      number=6, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\350\3071\001', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=4904,
  serialized_end=5155,
)


_UPDATESNIMATCHMETADATA = _descriptor.Descriptor(
  name='UpdateSniMatchMetadata',
  full_name='yandex.cloud.apploadbalancer.v1.UpdateSniMatchMetadata',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='load_balancer_id', full_name='yandex.cloud.apploadbalancer.v1.UpdateSniMatchMetadata.load_balancer_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='listener_name', full_name='yandex.cloud.apploadbalancer.v1.UpdateSniMatchMetadata.listener_name', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='sni_match_name', full_name='yandex.cloud.apploadbalancer.v1.UpdateSniMatchMetadata.sni_match_name', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=5157,
  serialized_end=5254,
)


_LISTLOADBALANCEROPERATIONSREQUEST = _descriptor.Descriptor(
  name='ListLoadBalancerOperationsRequest',
  full_name='yandex.cloud.apploadbalancer.v1.ListLoadBalancerOperationsRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='load_balancer_id', full_name='yandex.cloud.apploadbalancer.v1.ListLoadBalancerOperationsRequest.load_balancer_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\350\3071\001\212\3101\004<=50', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='page_size', full_name='yandex.cloud.apploadbalancer.v1.ListLoadBalancerOperationsRequest.page_size', index=1,
      number=2, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\372\3071\006<=1000', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='page_token', full_name='yandex.cloud.apploadbalancer.v1.ListLoadBalancerOperationsRequest.page_token', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\212\3101\005<=100', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=5257,
  serialized_end=5394,
)


_LISTLOADBALANCEROPERATIONSRESPONSE = _descriptor.Descriptor(
  name='ListLoadBalancerOperationsResponse',
  full_name='yandex.cloud.apploadbalancer.v1.ListLoadBalancerOperationsResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='operations', full_name='yandex.cloud.apploadbalancer.v1.ListLoadBalancerOperationsResponse.operations', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='next_page_token', full_name='yandex.cloud.apploadbalancer.v1.ListLoadBalancerOperationsResponse.next_page_token', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=5396,
  serialized_end=5512,
)

_LISTLOADBALANCERSRESPONSE.fields_by_name['load_balancers'].message_type = yandex_dot_cloud_dot_apploadbalancer_dot_v1_dot_load__balancer__pb2._LOADBALANCER
_UPDATELOADBALANCERREQUEST_LABELSENTRY.containing_type = _UPDATELOADBALANCERREQUEST
_UPDATELOADBALANCERREQUEST.fields_by_name['update_mask'].message_type = google_dot_protobuf_dot_field__mask__pb2._FIELDMASK
_UPDATELOADBALANCERREQUEST.fields_by_name['labels'].message_type = _UPDATELOADBALANCERREQUEST_LABELSENTRY
_UPDATELOADBALANCERREQUEST.fields_by_name['listener_specs'].message_type = _LISTENERSPEC
_UPDATELOADBALANCERREQUEST.fields_by_name['allocation_policy'].message_type = yandex_dot_cloud_dot_apploadbalancer_dot_v1_dot_load__balancer__pb2._ALLOCATIONPOLICY
_UPDATELOADBALANCERREQUEST.fields_by_name['auto_scale_policy'].message_type = yandex_dot_cloud_dot_apploadbalancer_dot_v1_dot_load__balancer__pb2._AUTOSCALEPOLICY
_UPDATELOADBALANCERREQUEST.fields_by_name['log_options'].message_type = yandex_dot_cloud_dot_apploadbalancer_dot_v1_dot_logging__pb2._LOGOPTIONS
_CREATELOADBALANCERREQUEST_LABELSENTRY.containing_type = _CREATELOADBALANCERREQUEST
_CREATELOADBALANCERREQUEST.fields_by_name['labels'].message_type = _CREATELOADBALANCERREQUEST_LABELSENTRY
_CREATELOADBALANCERREQUEST.fields_by_name['listener_specs'].message_type = _LISTENERSPEC
_CREATELOADBALANCERREQUEST.fields_by_name['allocation_policy'].message_type = yandex_dot_cloud_dot_apploadbalancer_dot_v1_dot_load__balancer__pb2._ALLOCATIONPOLICY
_CREATELOADBALANCERREQUEST.fields_by_name['auto_scale_policy'].message_type = yandex_dot_cloud_dot_apploadbalancer_dot_v1_dot_load__balancer__pb2._AUTOSCALEPOLICY
_CREATELOADBALANCERREQUEST.fields_by_name['log_options'].message_type = yandex_dot_cloud_dot_apploadbalancer_dot_v1_dot_logging__pb2._LOGOPTIONS
_ADDLISTENERREQUEST.fields_by_name['listener_spec'].message_type = _LISTENERSPEC
_UPDATELISTENERREQUEST.fields_by_name['update_mask'].message_type = google_dot_protobuf_dot_field__mask__pb2._FIELDMASK
_UPDATELISTENERREQUEST.fields_by_name['listener_spec'].message_type = _LISTENERSPEC
_ADDRESSSPEC.fields_by_name['external_ipv4_address_spec'].message_type = _EXTERNALIPV4ADDRESSSPEC
_ADDRESSSPEC.fields_by_name['internal_ipv4_address_spec'].message_type = _INTERNALIPV4ADDRESSSPEC
_ADDRESSSPEC.fields_by_name['external_ipv6_address_spec'].message_type = _EXTERNALIPV6ADDRESSSPEC
_ADDRESSSPEC.oneofs_by_name['address_spec'].fields.append(
  _ADDRESSSPEC.fields_by_name['external_ipv4_address_spec'])
_ADDRESSSPEC.fields_by_name['external_ipv4_address_spec'].containing_oneof = _ADDRESSSPEC.oneofs_by_name['address_spec']
_ADDRESSSPEC.oneofs_by_name['address_spec'].fields.append(
  _ADDRESSSPEC.fields_by_name['internal_ipv4_address_spec'])
_ADDRESSSPEC.fields_by_name['internal_ipv4_address_spec'].containing_oneof = _ADDRESSSPEC.oneofs_by_name['address_spec']
_ADDRESSSPEC.oneofs_by_name['address_spec'].fields.append(
  _ADDRESSSPEC.fields_by_name['external_ipv6_address_spec'])
_ADDRESSSPEC.fields_by_name['external_ipv6_address_spec'].containing_oneof = _ADDRESSSPEC.oneofs_by_name['address_spec']
_ENDPOINTSPEC.fields_by_name['address_specs'].message_type = _ADDRESSSPEC
_LISTENERSPEC.fields_by_name['endpoint_specs'].message_type = _ENDPOINTSPEC
_LISTENERSPEC.fields_by_name['http'].message_type = yandex_dot_cloud_dot_apploadbalancer_dot_v1_dot_load__balancer__pb2._HTTPLISTENER
_LISTENERSPEC.fields_by_name['tls'].message_type = yandex_dot_cloud_dot_apploadbalancer_dot_v1_dot_load__balancer__pb2._TLSLISTENER
_LISTENERSPEC.fields_by_name['stream'].message_type = yandex_dot_cloud_dot_apploadbalancer_dot_v1_dot_load__balancer__pb2._STREAMLISTENER
_LISTENERSPEC.oneofs_by_name['listener'].fields.append(
  _LISTENERSPEC.fields_by_name['http'])
_LISTENERSPEC.fields_by_name['http'].containing_oneof = _LISTENERSPEC.oneofs_by_name['listener']
_LISTENERSPEC.oneofs_by_name['listener'].fields.append(
  _LISTENERSPEC.fields_by_name['tls'])
_LISTENERSPEC.fields_by_name['tls'].containing_oneof = _LISTENERSPEC.oneofs_by_name['listener']
_LISTENERSPEC.oneofs_by_name['listener'].fields.append(
  _LISTENERSPEC.fields_by_name['stream'])
_LISTENERSPEC.fields_by_name['stream'].containing_oneof = _LISTENERSPEC.oneofs_by_name['listener']
_GETTARGETSTATESRESPONSE.fields_by_name['target_states'].message_type = yandex_dot_cloud_dot_apploadbalancer_dot_v1_dot_load__balancer__pb2._TARGETSTATE
_ADDSNIMATCHREQUEST.fields_by_name['handler'].message_type = yandex_dot_cloud_dot_apploadbalancer_dot_v1_dot_load__balancer__pb2._TLSHANDLER
_UPDATESNIMATCHREQUEST.fields_by_name['update_mask'].message_type = google_dot_protobuf_dot_field__mask__pb2._FIELDMASK
_UPDATESNIMATCHREQUEST.fields_by_name['handler'].message_type = yandex_dot_cloud_dot_apploadbalancer_dot_v1_dot_load__balancer__pb2._TLSHANDLER
_LISTLOADBALANCEROPERATIONSRESPONSE.fields_by_name['operations'].message_type = yandex_dot_cloud_dot_operation_dot_operation__pb2._OPERATION
DESCRIPTOR.message_types_by_name['GetLoadBalancerRequest'] = _GETLOADBALANCERREQUEST
DESCRIPTOR.message_types_by_name['ListLoadBalancersRequest'] = _LISTLOADBALANCERSREQUEST
DESCRIPTOR.message_types_by_name['ListLoadBalancersResponse'] = _LISTLOADBALANCERSRESPONSE
DESCRIPTOR.message_types_by_name['DeleteLoadBalancerRequest'] = _DELETELOADBALANCERREQUEST
DESCRIPTOR.message_types_by_name['DeleteLoadBalancerMetadata'] = _DELETELOADBALANCERMETADATA
DESCRIPTOR.message_types_by_name['UpdateLoadBalancerRequest'] = _UPDATELOADBALANCERREQUEST
DESCRIPTOR.message_types_by_name['UpdateLoadBalancerMetadata'] = _UPDATELOADBALANCERMETADATA
DESCRIPTOR.message_types_by_name['CreateLoadBalancerRequest'] = _CREATELOADBALANCERREQUEST
DESCRIPTOR.message_types_by_name['CreateLoadBalancerMetadata'] = _CREATELOADBALANCERMETADATA
DESCRIPTOR.message_types_by_name['StartLoadBalancerRequest'] = _STARTLOADBALANCERREQUEST
DESCRIPTOR.message_types_by_name['StartLoadBalancerMetadata'] = _STARTLOADBALANCERMETADATA
DESCRIPTOR.message_types_by_name['StopLoadBalancerRequest'] = _STOPLOADBALANCERREQUEST
DESCRIPTOR.message_types_by_name['StopLoadBalancerMetadata'] = _STOPLOADBALANCERMETADATA
DESCRIPTOR.message_types_by_name['AddListenerRequest'] = _ADDLISTENERREQUEST
DESCRIPTOR.message_types_by_name['AddListenerMetadata'] = _ADDLISTENERMETADATA
DESCRIPTOR.message_types_by_name['RemoveListenerRequest'] = _REMOVELISTENERREQUEST
DESCRIPTOR.message_types_by_name['RemoveListenerMetadata'] = _REMOVELISTENERMETADATA
DESCRIPTOR.message_types_by_name['UpdateListenerRequest'] = _UPDATELISTENERREQUEST
DESCRIPTOR.message_types_by_name['UpdateListenerMetadata'] = _UPDATELISTENERMETADATA
DESCRIPTOR.message_types_by_name['AddressSpec'] = _ADDRESSSPEC
DESCRIPTOR.message_types_by_name['ExternalIpv4AddressSpec'] = _EXTERNALIPV4ADDRESSSPEC
DESCRIPTOR.message_types_by_name['InternalIpv4AddressSpec'] = _INTERNALIPV4ADDRESSSPEC
DESCRIPTOR.message_types_by_name['ExternalIpv6AddressSpec'] = _EXTERNALIPV6ADDRESSSPEC
DESCRIPTOR.message_types_by_name['EndpointSpec'] = _ENDPOINTSPEC
DESCRIPTOR.message_types_by_name['ListenerSpec'] = _LISTENERSPEC
DESCRIPTOR.message_types_by_name['GetTargetStatesRequest'] = _GETTARGETSTATESREQUEST
DESCRIPTOR.message_types_by_name['GetTargetStatesResponse'] = _GETTARGETSTATESRESPONSE
DESCRIPTOR.message_types_by_name['AddSniMatchRequest'] = _ADDSNIMATCHREQUEST
DESCRIPTOR.message_types_by_name['AddSniMatchMetadata'] = _ADDSNIMATCHMETADATA
DESCRIPTOR.message_types_by_name['RemoveSniMatchRequest'] = _REMOVESNIMATCHREQUEST
DESCRIPTOR.message_types_by_name['RemoveSniMatchMetadata'] = _REMOVESNIMATCHMETADATA
DESCRIPTOR.message_types_by_name['UpdateSniMatchRequest'] = _UPDATESNIMATCHREQUEST
DESCRIPTOR.message_types_by_name['UpdateSniMatchMetadata'] = _UPDATESNIMATCHMETADATA
DESCRIPTOR.message_types_by_name['ListLoadBalancerOperationsRequest'] = _LISTLOADBALANCEROPERATIONSREQUEST
DESCRIPTOR.message_types_by_name['ListLoadBalancerOperationsResponse'] = _LISTLOADBALANCEROPERATIONSRESPONSE
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

GetLoadBalancerRequest = _reflection.GeneratedProtocolMessageType('GetLoadBalancerRequest', (_message.Message,), {
  'DESCRIPTOR' : _GETLOADBALANCERREQUEST,
  '__module__' : 'yandex.cloud.apploadbalancer.v1.load_balancer_service_pb2'
  # @@protoc_insertion_point(class_scope:yandex.cloud.apploadbalancer.v1.GetLoadBalancerRequest)
  })
_sym_db.RegisterMessage(GetLoadBalancerRequest)

ListLoadBalancersRequest = _reflection.GeneratedProtocolMessageType('ListLoadBalancersRequest', (_message.Message,), {
  'DESCRIPTOR' : _LISTLOADBALANCERSREQUEST,
  '__module__' : 'yandex.cloud.apploadbalancer.v1.load_balancer_service_pb2'
  # @@protoc_insertion_point(class_scope:yandex.cloud.apploadbalancer.v1.ListLoadBalancersRequest)
  })
_sym_db.RegisterMessage(ListLoadBalancersRequest)

ListLoadBalancersResponse = _reflection.GeneratedProtocolMessageType('ListLoadBalancersResponse', (_message.Message,), {
  'DESCRIPTOR' : _LISTLOADBALANCERSRESPONSE,
  '__module__' : 'yandex.cloud.apploadbalancer.v1.load_balancer_service_pb2'
  # @@protoc_insertion_point(class_scope:yandex.cloud.apploadbalancer.v1.ListLoadBalancersResponse)
  })
_sym_db.RegisterMessage(ListLoadBalancersResponse)

DeleteLoadBalancerRequest = _reflection.GeneratedProtocolMessageType('DeleteLoadBalancerRequest', (_message.Message,), {
  'DESCRIPTOR' : _DELETELOADBALANCERREQUEST,
  '__module__' : 'yandex.cloud.apploadbalancer.v1.load_balancer_service_pb2'
  # @@protoc_insertion_point(class_scope:yandex.cloud.apploadbalancer.v1.DeleteLoadBalancerRequest)
  })
_sym_db.RegisterMessage(DeleteLoadBalancerRequest)

DeleteLoadBalancerMetadata = _reflection.GeneratedProtocolMessageType('DeleteLoadBalancerMetadata', (_message.Message,), {
  'DESCRIPTOR' : _DELETELOADBALANCERMETADATA,
  '__module__' : 'yandex.cloud.apploadbalancer.v1.load_balancer_service_pb2'
  # @@protoc_insertion_point(class_scope:yandex.cloud.apploadbalancer.v1.DeleteLoadBalancerMetadata)
  })
_sym_db.RegisterMessage(DeleteLoadBalancerMetadata)

UpdateLoadBalancerRequest = _reflection.GeneratedProtocolMessageType('UpdateLoadBalancerRequest', (_message.Message,), {

  'LabelsEntry' : _reflection.GeneratedProtocolMessageType('LabelsEntry', (_message.Message,), {
    'DESCRIPTOR' : _UPDATELOADBALANCERREQUEST_LABELSENTRY,
    '__module__' : 'yandex.cloud.apploadbalancer.v1.load_balancer_service_pb2'
    # @@protoc_insertion_point(class_scope:yandex.cloud.apploadbalancer.v1.UpdateLoadBalancerRequest.LabelsEntry)
    })
  ,
  'DESCRIPTOR' : _UPDATELOADBALANCERREQUEST,
  '__module__' : 'yandex.cloud.apploadbalancer.v1.load_balancer_service_pb2'
  # @@protoc_insertion_point(class_scope:yandex.cloud.apploadbalancer.v1.UpdateLoadBalancerRequest)
  })
_sym_db.RegisterMessage(UpdateLoadBalancerRequest)
_sym_db.RegisterMessage(UpdateLoadBalancerRequest.LabelsEntry)

UpdateLoadBalancerMetadata = _reflection.GeneratedProtocolMessageType('UpdateLoadBalancerMetadata', (_message.Message,), {
  'DESCRIPTOR' : _UPDATELOADBALANCERMETADATA,
  '__module__' : 'yandex.cloud.apploadbalancer.v1.load_balancer_service_pb2'
  # @@protoc_insertion_point(class_scope:yandex.cloud.apploadbalancer.v1.UpdateLoadBalancerMetadata)
  })
_sym_db.RegisterMessage(UpdateLoadBalancerMetadata)

CreateLoadBalancerRequest = _reflection.GeneratedProtocolMessageType('CreateLoadBalancerRequest', (_message.Message,), {

  'LabelsEntry' : _reflection.GeneratedProtocolMessageType('LabelsEntry', (_message.Message,), {
    'DESCRIPTOR' : _CREATELOADBALANCERREQUEST_LABELSENTRY,
    '__module__' : 'yandex.cloud.apploadbalancer.v1.load_balancer_service_pb2'
    # @@protoc_insertion_point(class_scope:yandex.cloud.apploadbalancer.v1.CreateLoadBalancerRequest.LabelsEntry)
    })
  ,
  'DESCRIPTOR' : _CREATELOADBALANCERREQUEST,
  '__module__' : 'yandex.cloud.apploadbalancer.v1.load_balancer_service_pb2'
  # @@protoc_insertion_point(class_scope:yandex.cloud.apploadbalancer.v1.CreateLoadBalancerRequest)
  })
_sym_db.RegisterMessage(CreateLoadBalancerRequest)
_sym_db.RegisterMessage(CreateLoadBalancerRequest.LabelsEntry)

CreateLoadBalancerMetadata = _reflection.GeneratedProtocolMessageType('CreateLoadBalancerMetadata', (_message.Message,), {
  'DESCRIPTOR' : _CREATELOADBALANCERMETADATA,
  '__module__' : 'yandex.cloud.apploadbalancer.v1.load_balancer_service_pb2'
  # @@protoc_insertion_point(class_scope:yandex.cloud.apploadbalancer.v1.CreateLoadBalancerMetadata)
  })
_sym_db.RegisterMessage(CreateLoadBalancerMetadata)

StartLoadBalancerRequest = _reflection.GeneratedProtocolMessageType('StartLoadBalancerRequest', (_message.Message,), {
  'DESCRIPTOR' : _STARTLOADBALANCERREQUEST,
  '__module__' : 'yandex.cloud.apploadbalancer.v1.load_balancer_service_pb2'
  # @@protoc_insertion_point(class_scope:yandex.cloud.apploadbalancer.v1.StartLoadBalancerRequest)
  })
_sym_db.RegisterMessage(StartLoadBalancerRequest)

StartLoadBalancerMetadata = _reflection.GeneratedProtocolMessageType('StartLoadBalancerMetadata', (_message.Message,), {
  'DESCRIPTOR' : _STARTLOADBALANCERMETADATA,
  '__module__' : 'yandex.cloud.apploadbalancer.v1.load_balancer_service_pb2'
  # @@protoc_insertion_point(class_scope:yandex.cloud.apploadbalancer.v1.StartLoadBalancerMetadata)
  })
_sym_db.RegisterMessage(StartLoadBalancerMetadata)

StopLoadBalancerRequest = _reflection.GeneratedProtocolMessageType('StopLoadBalancerRequest', (_message.Message,), {
  'DESCRIPTOR' : _STOPLOADBALANCERREQUEST,
  '__module__' : 'yandex.cloud.apploadbalancer.v1.load_balancer_service_pb2'
  # @@protoc_insertion_point(class_scope:yandex.cloud.apploadbalancer.v1.StopLoadBalancerRequest)
  })
_sym_db.RegisterMessage(StopLoadBalancerRequest)

StopLoadBalancerMetadata = _reflection.GeneratedProtocolMessageType('StopLoadBalancerMetadata', (_message.Message,), {
  'DESCRIPTOR' : _STOPLOADBALANCERMETADATA,
  '__module__' : 'yandex.cloud.apploadbalancer.v1.load_balancer_service_pb2'
  # @@protoc_insertion_point(class_scope:yandex.cloud.apploadbalancer.v1.StopLoadBalancerMetadata)
  })
_sym_db.RegisterMessage(StopLoadBalancerMetadata)

AddListenerRequest = _reflection.GeneratedProtocolMessageType('AddListenerRequest', (_message.Message,), {
  'DESCRIPTOR' : _ADDLISTENERREQUEST,
  '__module__' : 'yandex.cloud.apploadbalancer.v1.load_balancer_service_pb2'
  # @@protoc_insertion_point(class_scope:yandex.cloud.apploadbalancer.v1.AddListenerRequest)
  })
_sym_db.RegisterMessage(AddListenerRequest)

AddListenerMetadata = _reflection.GeneratedProtocolMessageType('AddListenerMetadata', (_message.Message,), {
  'DESCRIPTOR' : _ADDLISTENERMETADATA,
  '__module__' : 'yandex.cloud.apploadbalancer.v1.load_balancer_service_pb2'
  # @@protoc_insertion_point(class_scope:yandex.cloud.apploadbalancer.v1.AddListenerMetadata)
  })
_sym_db.RegisterMessage(AddListenerMetadata)

RemoveListenerRequest = _reflection.GeneratedProtocolMessageType('RemoveListenerRequest', (_message.Message,), {
  'DESCRIPTOR' : _REMOVELISTENERREQUEST,
  '__module__' : 'yandex.cloud.apploadbalancer.v1.load_balancer_service_pb2'
  # @@protoc_insertion_point(class_scope:yandex.cloud.apploadbalancer.v1.RemoveListenerRequest)
  })
_sym_db.RegisterMessage(RemoveListenerRequest)

RemoveListenerMetadata = _reflection.GeneratedProtocolMessageType('RemoveListenerMetadata', (_message.Message,), {
  'DESCRIPTOR' : _REMOVELISTENERMETADATA,
  '__module__' : 'yandex.cloud.apploadbalancer.v1.load_balancer_service_pb2'
  # @@protoc_insertion_point(class_scope:yandex.cloud.apploadbalancer.v1.RemoveListenerMetadata)
  })
_sym_db.RegisterMessage(RemoveListenerMetadata)

UpdateListenerRequest = _reflection.GeneratedProtocolMessageType('UpdateListenerRequest', (_message.Message,), {
  'DESCRIPTOR' : _UPDATELISTENERREQUEST,
  '__module__' : 'yandex.cloud.apploadbalancer.v1.load_balancer_service_pb2'
  # @@protoc_insertion_point(class_scope:yandex.cloud.apploadbalancer.v1.UpdateListenerRequest)
  })
_sym_db.RegisterMessage(UpdateListenerRequest)

UpdateListenerMetadata = _reflection.GeneratedProtocolMessageType('UpdateListenerMetadata', (_message.Message,), {
  'DESCRIPTOR' : _UPDATELISTENERMETADATA,
  '__module__' : 'yandex.cloud.apploadbalancer.v1.load_balancer_service_pb2'
  # @@protoc_insertion_point(class_scope:yandex.cloud.apploadbalancer.v1.UpdateListenerMetadata)
  })
_sym_db.RegisterMessage(UpdateListenerMetadata)

AddressSpec = _reflection.GeneratedProtocolMessageType('AddressSpec', (_message.Message,), {
  'DESCRIPTOR' : _ADDRESSSPEC,
  '__module__' : 'yandex.cloud.apploadbalancer.v1.load_balancer_service_pb2'
  # @@protoc_insertion_point(class_scope:yandex.cloud.apploadbalancer.v1.AddressSpec)
  })
_sym_db.RegisterMessage(AddressSpec)

ExternalIpv4AddressSpec = _reflection.GeneratedProtocolMessageType('ExternalIpv4AddressSpec', (_message.Message,), {
  'DESCRIPTOR' : _EXTERNALIPV4ADDRESSSPEC,
  '__module__' : 'yandex.cloud.apploadbalancer.v1.load_balancer_service_pb2'
  # @@protoc_insertion_point(class_scope:yandex.cloud.apploadbalancer.v1.ExternalIpv4AddressSpec)
  })
_sym_db.RegisterMessage(ExternalIpv4AddressSpec)

InternalIpv4AddressSpec = _reflection.GeneratedProtocolMessageType('InternalIpv4AddressSpec', (_message.Message,), {
  'DESCRIPTOR' : _INTERNALIPV4ADDRESSSPEC,
  '__module__' : 'yandex.cloud.apploadbalancer.v1.load_balancer_service_pb2'
  # @@protoc_insertion_point(class_scope:yandex.cloud.apploadbalancer.v1.InternalIpv4AddressSpec)
  })
_sym_db.RegisterMessage(InternalIpv4AddressSpec)

ExternalIpv6AddressSpec = _reflection.GeneratedProtocolMessageType('ExternalIpv6AddressSpec', (_message.Message,), {
  'DESCRIPTOR' : _EXTERNALIPV6ADDRESSSPEC,
  '__module__' : 'yandex.cloud.apploadbalancer.v1.load_balancer_service_pb2'
  # @@protoc_insertion_point(class_scope:yandex.cloud.apploadbalancer.v1.ExternalIpv6AddressSpec)
  })
_sym_db.RegisterMessage(ExternalIpv6AddressSpec)

EndpointSpec = _reflection.GeneratedProtocolMessageType('EndpointSpec', (_message.Message,), {
  'DESCRIPTOR' : _ENDPOINTSPEC,
  '__module__' : 'yandex.cloud.apploadbalancer.v1.load_balancer_service_pb2'
  # @@protoc_insertion_point(class_scope:yandex.cloud.apploadbalancer.v1.EndpointSpec)
  })
_sym_db.RegisterMessage(EndpointSpec)

ListenerSpec = _reflection.GeneratedProtocolMessageType('ListenerSpec', (_message.Message,), {
  'DESCRIPTOR' : _LISTENERSPEC,
  '__module__' : 'yandex.cloud.apploadbalancer.v1.load_balancer_service_pb2'
  # @@protoc_insertion_point(class_scope:yandex.cloud.apploadbalancer.v1.ListenerSpec)
  })
_sym_db.RegisterMessage(ListenerSpec)

GetTargetStatesRequest = _reflection.GeneratedProtocolMessageType('GetTargetStatesRequest', (_message.Message,), {
  'DESCRIPTOR' : _GETTARGETSTATESREQUEST,
  '__module__' : 'yandex.cloud.apploadbalancer.v1.load_balancer_service_pb2'
  # @@protoc_insertion_point(class_scope:yandex.cloud.apploadbalancer.v1.GetTargetStatesRequest)
  })
_sym_db.RegisterMessage(GetTargetStatesRequest)

GetTargetStatesResponse = _reflection.GeneratedProtocolMessageType('GetTargetStatesResponse', (_message.Message,), {
  'DESCRIPTOR' : _GETTARGETSTATESRESPONSE,
  '__module__' : 'yandex.cloud.apploadbalancer.v1.load_balancer_service_pb2'
  # @@protoc_insertion_point(class_scope:yandex.cloud.apploadbalancer.v1.GetTargetStatesResponse)
  })
_sym_db.RegisterMessage(GetTargetStatesResponse)

AddSniMatchRequest = _reflection.GeneratedProtocolMessageType('AddSniMatchRequest', (_message.Message,), {
  'DESCRIPTOR' : _ADDSNIMATCHREQUEST,
  '__module__' : 'yandex.cloud.apploadbalancer.v1.load_balancer_service_pb2'
  # @@protoc_insertion_point(class_scope:yandex.cloud.apploadbalancer.v1.AddSniMatchRequest)
  })
_sym_db.RegisterMessage(AddSniMatchRequest)

AddSniMatchMetadata = _reflection.GeneratedProtocolMessageType('AddSniMatchMetadata', (_message.Message,), {
  'DESCRIPTOR' : _ADDSNIMATCHMETADATA,
  '__module__' : 'yandex.cloud.apploadbalancer.v1.load_balancer_service_pb2'
  # @@protoc_insertion_point(class_scope:yandex.cloud.apploadbalancer.v1.AddSniMatchMetadata)
  })
_sym_db.RegisterMessage(AddSniMatchMetadata)

RemoveSniMatchRequest = _reflection.GeneratedProtocolMessageType('RemoveSniMatchRequest', (_message.Message,), {
  'DESCRIPTOR' : _REMOVESNIMATCHREQUEST,
  '__module__' : 'yandex.cloud.apploadbalancer.v1.load_balancer_service_pb2'
  # @@protoc_insertion_point(class_scope:yandex.cloud.apploadbalancer.v1.RemoveSniMatchRequest)
  })
_sym_db.RegisterMessage(RemoveSniMatchRequest)

RemoveSniMatchMetadata = _reflection.GeneratedProtocolMessageType('RemoveSniMatchMetadata', (_message.Message,), {
  'DESCRIPTOR' : _REMOVESNIMATCHMETADATA,
  '__module__' : 'yandex.cloud.apploadbalancer.v1.load_balancer_service_pb2'
  # @@protoc_insertion_point(class_scope:yandex.cloud.apploadbalancer.v1.RemoveSniMatchMetadata)
  })
_sym_db.RegisterMessage(RemoveSniMatchMetadata)

UpdateSniMatchRequest = _reflection.GeneratedProtocolMessageType('UpdateSniMatchRequest', (_message.Message,), {
  'DESCRIPTOR' : _UPDATESNIMATCHREQUEST,
  '__module__' : 'yandex.cloud.apploadbalancer.v1.load_balancer_service_pb2'
  # @@protoc_insertion_point(class_scope:yandex.cloud.apploadbalancer.v1.UpdateSniMatchRequest)
  })
_sym_db.RegisterMessage(UpdateSniMatchRequest)

UpdateSniMatchMetadata = _reflection.GeneratedProtocolMessageType('UpdateSniMatchMetadata', (_message.Message,), {
  'DESCRIPTOR' : _UPDATESNIMATCHMETADATA,
  '__module__' : 'yandex.cloud.apploadbalancer.v1.load_balancer_service_pb2'
  # @@protoc_insertion_point(class_scope:yandex.cloud.apploadbalancer.v1.UpdateSniMatchMetadata)
  })
_sym_db.RegisterMessage(UpdateSniMatchMetadata)

ListLoadBalancerOperationsRequest = _reflection.GeneratedProtocolMessageType('ListLoadBalancerOperationsRequest', (_message.Message,), {
  'DESCRIPTOR' : _LISTLOADBALANCEROPERATIONSREQUEST,
  '__module__' : 'yandex.cloud.apploadbalancer.v1.load_balancer_service_pb2'
  # @@protoc_insertion_point(class_scope:yandex.cloud.apploadbalancer.v1.ListLoadBalancerOperationsRequest)
  })
_sym_db.RegisterMessage(ListLoadBalancerOperationsRequest)

ListLoadBalancerOperationsResponse = _reflection.GeneratedProtocolMessageType('ListLoadBalancerOperationsResponse', (_message.Message,), {
  'DESCRIPTOR' : _LISTLOADBALANCEROPERATIONSRESPONSE,
  '__module__' : 'yandex.cloud.apploadbalancer.v1.load_balancer_service_pb2'
  # @@protoc_insertion_point(class_scope:yandex.cloud.apploadbalancer.v1.ListLoadBalancerOperationsResponse)
  })
_sym_db.RegisterMessage(ListLoadBalancerOperationsResponse)


DESCRIPTOR._options = None
_GETLOADBALANCERREQUEST.fields_by_name['load_balancer_id']._options = None
_LISTLOADBALANCERSREQUEST.fields_by_name['folder_id']._options = None
_LISTLOADBALANCERSREQUEST.fields_by_name['page_size']._options = None
_LISTLOADBALANCERSREQUEST.fields_by_name['page_token']._options = None
_LISTLOADBALANCERSREQUEST.fields_by_name['filter']._options = None
_DELETELOADBALANCERREQUEST.fields_by_name['load_balancer_id']._options = None
_UPDATELOADBALANCERREQUEST_LABELSENTRY._options = None
_UPDATELOADBALANCERREQUEST.fields_by_name['load_balancer_id']._options = None
_UPDATELOADBALANCERREQUEST.fields_by_name['name']._options = None
_UPDATELOADBALANCERREQUEST.fields_by_name['description']._options = None
_UPDATELOADBALANCERREQUEST.fields_by_name['labels']._options = None
_CREATELOADBALANCERREQUEST_LABELSENTRY._options = None
_CREATELOADBALANCERREQUEST.fields_by_name['folder_id']._options = None
_CREATELOADBALANCERREQUEST.fields_by_name['name']._options = None
_CREATELOADBALANCERREQUEST.fields_by_name['description']._options = None
_CREATELOADBALANCERREQUEST.fields_by_name['labels']._options = None
_CREATELOADBALANCERREQUEST.fields_by_name['region_id']._options = None
_CREATELOADBALANCERREQUEST.fields_by_name['network_id']._options = None
_STARTLOADBALANCERREQUEST.fields_by_name['load_balancer_id']._options = None
_STOPLOADBALANCERREQUEST.fields_by_name['load_balancer_id']._options = None
_ADDLISTENERREQUEST.fields_by_name['load_balancer_id']._options = None
_ADDLISTENERREQUEST.fields_by_name['listener_spec']._options = None
_REMOVELISTENERREQUEST.fields_by_name['load_balancer_id']._options = None
_REMOVELISTENERREQUEST.fields_by_name['name']._options = None
_UPDATELISTENERREQUEST.fields_by_name['load_balancer_id']._options = None
_UPDATELISTENERREQUEST.fields_by_name['listener_spec']._options = None
_ADDRESSSPEC.oneofs_by_name['address_spec']._options = None
_ENDPOINTSPEC.fields_by_name['address_specs']._options = None
_ENDPOINTSPEC.fields_by_name['ports']._options = None
_LISTENERSPEC.oneofs_by_name['listener']._options = None
_LISTENERSPEC.fields_by_name['name']._options = None
_LISTENERSPEC.fields_by_name['endpoint_specs']._options = None
_GETTARGETSTATESREQUEST.fields_by_name['load_balancer_id']._options = None
_GETTARGETSTATESREQUEST.fields_by_name['backend_group_id']._options = None
_GETTARGETSTATESREQUEST.fields_by_name['target_group_id']._options = None
_ADDSNIMATCHREQUEST.fields_by_name['load_balancer_id']._options = None
_ADDSNIMATCHREQUEST.fields_by_name['listener_name']._options = None
_ADDSNIMATCHREQUEST.fields_by_name['name']._options = None
_ADDSNIMATCHREQUEST.fields_by_name['server_names']._options = None
_ADDSNIMATCHREQUEST.fields_by_name['handler']._options = None
_REMOVESNIMATCHREQUEST.fields_by_name['load_balancer_id']._options = None
_REMOVESNIMATCHREQUEST.fields_by_name['listener_name']._options = None
_REMOVESNIMATCHREQUEST.fields_by_name['sni_match_name']._options = None
_UPDATESNIMATCHREQUEST.fields_by_name['load_balancer_id']._options = None
_UPDATESNIMATCHREQUEST.fields_by_name['listener_name']._options = None
_UPDATESNIMATCHREQUEST.fields_by_name['name']._options = None
_UPDATESNIMATCHREQUEST.fields_by_name['server_names']._options = None
_UPDATESNIMATCHREQUEST.fields_by_name['handler']._options = None
_LISTLOADBALANCEROPERATIONSREQUEST.fields_by_name['load_balancer_id']._options = None
_LISTLOADBALANCEROPERATIONSREQUEST.fields_by_name['page_size']._options = None
_LISTLOADBALANCEROPERATIONSREQUEST.fields_by_name['page_token']._options = None

_LOADBALANCERSERVICE = _descriptor.ServiceDescriptor(
  name='LoadBalancerService',
  full_name='yandex.cloud.apploadbalancer.v1.LoadBalancerService',
  file=DESCRIPTOR,
  index=0,
  serialized_options=None,
  create_key=_descriptor._internal_create_key,
  serialized_start=5515,
  serialized_end=8822,
  methods=[
  _descriptor.MethodDescriptor(
    name='Get',
    full_name='yandex.cloud.apploadbalancer.v1.LoadBalancerService.Get',
    index=0,
    containing_service=None,
    input_type=_GETLOADBALANCERREQUEST,
    output_type=yandex_dot_cloud_dot_apploadbalancer_dot_v1_dot_load__balancer__pb2._LOADBALANCER,
    serialized_options=b'\202\323\344\223\0026\0224/apploadbalancer/v1/loadBalancers/{load_balancer_id}',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='List',
    full_name='yandex.cloud.apploadbalancer.v1.LoadBalancerService.List',
    index=1,
    containing_service=None,
    input_type=_LISTLOADBALANCERSREQUEST,
    output_type=_LISTLOADBALANCERSRESPONSE,
    serialized_options=b'\202\323\344\223\002#\022!/apploadbalancer/v1/loadBalancers',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='Create',
    full_name='yandex.cloud.apploadbalancer.v1.LoadBalancerService.Create',
    index=2,
    containing_service=None,
    input_type=_CREATELOADBALANCERREQUEST,
    output_type=yandex_dot_cloud_dot_operation_dot_operation__pb2._OPERATION,
    serialized_options=b'\202\323\344\223\002&\"!/apploadbalancer/v1/loadBalancers:\001*\262\322**\n\032CreateLoadBalancerMetadata\022\014LoadBalancer',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='Update',
    full_name='yandex.cloud.apploadbalancer.v1.LoadBalancerService.Update',
    index=3,
    containing_service=None,
    input_type=_UPDATELOADBALANCERREQUEST,
    output_type=yandex_dot_cloud_dot_operation_dot_operation__pb2._OPERATION,
    serialized_options=b'\202\323\344\223\002924/apploadbalancer/v1/loadBalancers/{load_balancer_id}:\001*\262\322**\n\032UpdateLoadBalancerMetadata\022\014LoadBalancer',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='Delete',
    full_name='yandex.cloud.apploadbalancer.v1.LoadBalancerService.Delete',
    index=4,
    containing_service=None,
    input_type=_DELETELOADBALANCERREQUEST,
    output_type=yandex_dot_cloud_dot_operation_dot_operation__pb2._OPERATION,
    serialized_options=b'\202\323\344\223\0026*4/apploadbalancer/v1/loadBalancers/{load_balancer_id}\262\322*3\n\032DeleteLoadBalancerMetadata\022\025google.protobuf.Empty',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='Start',
    full_name='yandex.cloud.apploadbalancer.v1.LoadBalancerService.Start',
    index=5,
    containing_service=None,
    input_type=_STARTLOADBALANCERREQUEST,
    output_type=yandex_dot_cloud_dot_operation_dot_operation__pb2._OPERATION,
    serialized_options=b'\202\323\344\223\002<\":/apploadbalancer/v1/loadBalancers/{load_balancer_id}:start\262\322*)\n\031StartLoadBalancerMetadata\022\014LoadBalancer',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='Stop',
    full_name='yandex.cloud.apploadbalancer.v1.LoadBalancerService.Stop',
    index=6,
    containing_service=None,
    input_type=_STOPLOADBALANCERREQUEST,
    output_type=yandex_dot_cloud_dot_operation_dot_operation__pb2._OPERATION,
    serialized_options=b'\202\323\344\223\002;\"9/apploadbalancer/v1/loadBalancers/{load_balancer_id}:stop\262\322*(\n\030StopLoadBalancerMetadata\022\014LoadBalancer',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='AddListener',
    full_name='yandex.cloud.apploadbalancer.v1.LoadBalancerService.AddListener',
    index=7,
    containing_service=None,
    input_type=_ADDLISTENERREQUEST,
    output_type=yandex_dot_cloud_dot_operation_dot_operation__pb2._OPERATION,
    serialized_options=b'\202\323\344\223\002E\"@/apploadbalancer/v1/loadBalancers/{load_balancer_id}:addListener:\001*\262\322*#\n\023AddListenerMetadata\022\014LoadBalancer',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='RemoveListener',
    full_name='yandex.cloud.apploadbalancer.v1.LoadBalancerService.RemoveListener',
    index=8,
    containing_service=None,
    input_type=_REMOVELISTENERREQUEST,
    output_type=yandex_dot_cloud_dot_operation_dot_operation__pb2._OPERATION,
    serialized_options=b'\202\323\344\223\002H\"C/apploadbalancer/v1/loadBalancers/{load_balancer_id}:removeListener:\001*\262\322*&\n\026RemoveListenerMetadata\022\014LoadBalancer',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='UpdateListener',
    full_name='yandex.cloud.apploadbalancer.v1.LoadBalancerService.UpdateListener',
    index=9,
    containing_service=None,
    input_type=_UPDATELISTENERREQUEST,
    output_type=yandex_dot_cloud_dot_operation_dot_operation__pb2._OPERATION,
    serialized_options=b'\202\323\344\223\002H\"C/apploadbalancer/v1/loadBalancers/{load_balancer_id}:updateListener:\001*\262\322*&\n\026UpdateListenerMetadata\022\014LoadBalancer',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='AddSniMatch',
    full_name='yandex.cloud.apploadbalancer.v1.LoadBalancerService.AddSniMatch',
    index=10,
    containing_service=None,
    input_type=_ADDSNIMATCHREQUEST,
    output_type=yandex_dot_cloud_dot_operation_dot_operation__pb2._OPERATION,
    serialized_options=b'\202\323\344\223\002E\"@/apploadbalancer/v1/loadBalancers/{load_balancer_id}:addSniMatch:\001*\262\322*,\n\023AddSniMatchMetadata\022\025google.protobuf.Empty',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='UpdateSniMatch',
    full_name='yandex.cloud.apploadbalancer.v1.LoadBalancerService.UpdateSniMatch',
    index=11,
    containing_service=None,
    input_type=_UPDATESNIMATCHREQUEST,
    output_type=yandex_dot_cloud_dot_operation_dot_operation__pb2._OPERATION,
    serialized_options=b'\202\323\344\223\002H\"C/apploadbalancer/v1/loadBalancers/{load_balancer_id}:updateSniMatch:\001*\262\322*/\n\026UpdateSniMatchMetadata\022\025google.protobuf.Empty',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='RemoveSniMatch',
    full_name='yandex.cloud.apploadbalancer.v1.LoadBalancerService.RemoveSniMatch',
    index=12,
    containing_service=None,
    input_type=_REMOVESNIMATCHREQUEST,
    output_type=yandex_dot_cloud_dot_operation_dot_operation__pb2._OPERATION,
    serialized_options=b'\202\323\344\223\002H\"C/apploadbalancer/v1/loadBalancers/{load_balancer_id}:removeSniMatch:\001*\262\322*/\n\026RemoveSniMatchMetadata\022\025google.protobuf.Empty',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='GetTargetStates',
    full_name='yandex.cloud.apploadbalancer.v1.LoadBalancerService.GetTargetStates',
    index=13,
    containing_service=None,
    input_type=_GETTARGETSTATESREQUEST,
    output_type=_GETTARGETSTATESRESPONSE,
    serialized_options=b'\202\323\344\223\002h\022f/apploadbalancer/v1/loadBalancers/{load_balancer_id}/targetStates/{backend_group_id}/{target_group_id}',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='ListOperations',
    full_name='yandex.cloud.apploadbalancer.v1.LoadBalancerService.ListOperations',
    index=14,
    containing_service=None,
    input_type=_LISTLOADBALANCEROPERATIONSREQUEST,
    output_type=_LISTLOADBALANCEROPERATIONSRESPONSE,
    serialized_options=b'\202\323\344\223\002A\022?/apploadbalancer/v1/loadBalancers/{load_balancer_id}/operations',
    create_key=_descriptor._internal_create_key,
  ),
])
_sym_db.RegisterServiceDescriptor(_LOADBALANCERSERVICE)

DESCRIPTOR.services_by_name['LoadBalancerService'] = _LOADBALANCERSERVICE

# @@protoc_insertion_point(module_scope)
